--[[  LS Chat 2.6.2

original : Aaike Van Roekeghem - a.k.a [LoSt]Madness
current : Anavar of Llane

Enables you to remove the buttons next to the chatframes.
The buttons are still clickable eventhough they are invisible , the "Goto Bottom" button will still flash if you are not at the bottom as well. 
The mod also allows you to scroll in the chatframes with the mousewheel and timestamps chat messages as they come in (with or without seconds).

anything this addon does can be enabled/disabled in its options window. open it up with the 
slashcommand : /lschat

changes in 2.6
- added option to suppress duel messages
- added option to turn off chat text fading (code from Scre3m added)
- fixed time stamp code (thanks to Napgravy)

changes in 2.5
- improved the Anti-Emote Spam code

changes in 2.4
- added EditBox on top option

changes in 2.3 :
- added Anti-Emote Spam routine .. credits to AntiEmoteSpam v1.0 by by Lizzo for the code

changes in 2.2 :
- added Alt-Arrow Key overide

changes in 2.0 :
- updated for new LUA commands (removed table calls)
- updated toc

changes in 1.2 :
- added support for  MyAddons
- changed toc file for wow version 1600
- empty chat messages will not be displayed with timestamps

changes in 1.1 : 
- There is now an option to disable the chat buttons completely

]]--

--Default Configuration
LSChatConfig = {};
LSChatConfig.HideButtons = false;
LSChatConfig.DisableButtons = false;
LSChatConfig.HideEmote = false;
LSChatConfig.StampEnabled = false;
LSChatConfig.StampSeconds = false;
LSChatConfig.StampStyle = false;
LSChatConfig.ArrowKeys = false;
LSChatConfig.EmoteSpam = false;
LSChatConfig.DuelSpam = false;
LSChatConfig.EditBoxUp = false;
LSChatConfig.ChatTextFading = false;

LSChat = {
	
	--local vars
	chatbuttons = {"DownButton",
		"UpButton",
		"BottomButton"
		};

	chatFrames = 7;
	
	--Public Functions
	ToggleButtons = function()
		if(LSChatConfig.HideButtons) then
			LSChat.Show();
		else
			LSChat.Hide();
		end
	end;
	
	ToggleEnabled = function()
		if(LSChatConfig.DisableButtons) then
			LSChat.Enable();
		else
			LSChat.Disable();
		end
	end;
	
	ToggleEmote = function()
		if(ChatFrameMenuButton:IsVisible()) then
			ChatFrameMenuButton:Hide()
			LSChatConfig.HideEmote = true;
		else
			ChatFrameMenuButton:Show()
			LSChatConfig.HideEmote = false;
		end
	end;
	
	ToggleChatTextFading = function() 
		if(LSChatConfig.ChatTextFading) then
			LSChatConfig.ChatTextFading = false;
			for i=1,7 do 
				getglobal("ChatFrame"..i):SetFading(1);
				getglobal("ChatFrame"..i):SetTimeVisible(300);	
			end	
		else
			LSChatConfig.ChatTextFading = true
			for i=1,7 do getglobal("ChatFrame"..i):SetFading(nil) end
		end
	end;

	ToggleMousewheel = function() 
		if(LSChatConfig.Mousewheel) then
			LSChatConfig.Mousewheel = false;
		else
			LSChatConfig.Mousewheel = true;
		end
	end;
	
	ToggleArrowKeys = function() 
		if(LSChatConfig.ArrowKeys) then
			LSChatConfig.ArrowKeys = false;
			ChatFrameEditBox:SetAltArrowKeyMode(true);			
		else
			LSChatConfig.ArrowKeys = true;
			ChatFrameEditBox:SetAltArrowKeyMode(false);						
		end
	end;	
	
	ToggleEditBoxUp = function() 
		if(LSChatConfig.EditBoxUp) then
			LSChatConfig.EditBoxUp = false;
			ChatFrameEditBox:ClearAllPoints();
			ChatFrameEditBox:SetPoint("TOPLEFT",  "ChatFrame1", "BOTTOMLEFT",  -5, 0);
			ChatFrameEditBox:SetPoint("TOPRIGHT", "ChatFrame1", "BOTTOMRIGHT",  5, 0);
		else
			LSChatConfig.EditBoxUp = true;				
			ChatFrameEditBox:ClearAllPoints();
			ChatFrameEditBox:SetPoint("BOTTOMLEFT",  "ChatFrame1", "TOPLEFT",  -5, 0);
			ChatFrameEditBox:SetPoint("BOTTOMRIGHT", "ChatFrame1", "TOPRIGHT",  5, 0);
		end
	end;	

	ToggleEmoteSpam = function() 
		if(LSChatConfig.EmoteSpam) then
			LSChatConfig.EmoteSpam = false;
		else
			LSChatConfig.EmoteSpam = true;				
		end
	end;	
	
	
	ToggleDuelSpam = function() 
		if(LSChatConfig.DuelSpam) then
			LSChatConfig.DuelSpam = false;
		else
			LSChatConfig.DuelSpam = true;				
		end
	end;		
	
	ToggleStamp = function()
		if(LSChatConfig.StampEnabled)then 
			LSChatConfig.StampEnabled = false;
		else
			LSChatConfig.StampEnabled = true;
		end
	end;
	
	ToggleStampSeconds = function()
		if(LSChatConfig.StampSeconds)then 
			LSChatConfig.StampSeconds = false;
		else
			LSChatConfig.StampSeconds = true;
		end
	end;
	
	ToggleStampStyle = function()
		if(LSChatConfig.StampStyle)then 
			LSChatConfig.StampStyle = false;
		else
			LSChatConfig.StampStyle = true;
		end
	end;

	
	--Private Functions
	OnLoad = function()
		
		-- Setup For Anti-Emote Spam
         	lastemote = "";
         	lastlastemote = "";		
			
		-- Hook ChatFrame_OnEvent so we can hook AddMessage
		Original_ChatFrame_OnEvent = ChatFrame_OnEvent;
		ChatFrame_OnEvent = LSChat.OnEvent;
		
		SlashCmdList["LOST_CHAT"] = LSChat_ToggleOptions;
		SLASH_LOST_CHAT1 = "/lschat";
	
		
	end;
	
	OnEvent = function(event)
		
		if (event == "VARIABLES_LOADED") then
			
			if (myAddOnsFrame) then
			myAddOnsList.LS_Chat = {
			name = "LS Chat (Anavar Update)",
			description = "Removes chat buttons, enables mousewheel scrolling and more",
			version = "2.6.1", category = MYADDONS_CATEGORY_CHAT,
			frame = "LSChat_Options",
			optionsframe = "LSChat_Options"
			};
			end

			if(LSChatConfig.HideButtons) then
				LSChat.Hide();
			else
				LSChat.Show();
			end
			
			if(LSChatConfig.HideEmote) then
				ChatFrameMenuButton:Hide()
			else
				ChatFrameMenuButton:Show()
			end

			if(LSChatConfig.ChatTextFading) then
				for i=1,7 do getglobal("ChatFrame"..i):SetFading(nil) end			
			end

			if(LSChatConfig.ArrowKeys) then
				ChatFrameEditBox:SetAltArrowKeyMode(false);			
			else
				ChatFrameEditBox:SetAltArrowKeyMode(true);						
			end

			if(LSChatConfig.EditBoxUp) then
				ChatFrameEditBox:ClearAllPoints();
				ChatFrameEditBox:SetPoint("BOTTOMLEFT",  "ChatFrame1", "TOPLEFT",  -5, 0);
				ChatFrameEditBox:SetPoint("BOTTOMRIGHT", "ChatFrame1", "TOPRIGHT",  5, 0);
			end
			
		end

		-- duel spam ?
		
		if (event == "CHAT_MSG_SYSTEM") and (LSChatConfig.DuelSpam) then
			if (string.find(arg1, "has defeated") and string.find(arg1, "in a duel")) or string.find(arg1, "has fled from") then
				return;
			end
		end
		
		-- emote spam ?
		
		if (event == "CHAT_MSG_TEXT_EMOTE") and (LSChatConfig.EmoteSpam) then
			if arg1 == lastemote or arg1 == lastlastemote then
                         	lastlastemote = lastemote;
                         	lastemote = arg1;
                         	return;
			end;
                 	lastlastemote = lastemote;
                 	lastemote = arg1;
		end;
		
		Original_ChatFrame_OnEvent(event); --call the real ChatFrame_OnEvent function
		--if we haven't already done so, hook the AddMessage function
		if(not this.Original_AddMessage) then
			this.Original_AddMessage = this.AddMessage;
			this.AddMessage = LSChat.AddMessage;
		end
	
	end;
	
	Disable = function()
		for i=1, LSChat.chatFrames, 1 do
			for button in pairs(LSChat.chatbuttons) do
				b = getglobal("ChatFrame".. i .. LSChat.chatbuttons[button]);
				b:EnableMouse(0)
			end
		end
		LSChatConfig.DisableButtons = true;
	end;
	
	Enable = function()
		for i=1, LSChat.chatFrames, 1 do
			for button in pairs(LSChat.chatbuttons) do
				b = getglobal("ChatFrame".. i .. LSChat.chatbuttons[button]);
				b:EnableMouse(1)
			end
		end
		LSChatConfig.DisableButtons = false;
	end;
	
	
			
	Hide = function()		
		for i=1, LSChat.chatFrames, 1 do
			for button in pairs(LSChat.chatbuttons) do
				b = getglobal("ChatFrame".. i .. LSChat.chatbuttons[button]);
				b:DisableDrawLayer();
			end
		end
		LSChatConfig.HideButtons = true;
	end;
	
	Show = function()
		for i=1, LSChat.chatFrames, 1 do
			for button in pairs(LSChat.chatbuttons) do
			b = getglobal("ChatFrame".. i .. LSChat.chatbuttons[button]);
				b:EnableDrawLayer();
			end
		end
		LSChatConfig.HideButtons = false;
	end;

	
	AddMessage = function(this, msg, r, g, b, id)
		if msg ~= nil then
			if(LSChatConfig.StampEnabled) then
				local stamp
				local AMPM
				if (LSChatConfig.StampStyle) then
					hour=date("%H")
					AMPM=""
				else
					hour=date("%I")
					AMPM=strlower(date("%p"))
				end
				local minute=date("%M")
				local second=date("%S")
				stamp = "[" .. hour .. ":" .. minute
				if (LSChatConfig.StampSeconds) then
					stamp = stamp .. ":" .. second
				end
				msg = stamp .. AMPM .. "] " .. msg
			end
			this:Original_AddMessage(msg, r, g, b, id); --call the real AddMessage function
		end
	end;

}

